Python package to read, write and analyse CPACS AeroPerformanceMaps.

You need to have TIXI and TIGL install on your computer to use this package. 

Install with pip
================

.. code-block:: bash

   $ pip install cpacspy

To build and install locally:
=============================

.. code-block:: bash
   $ cd cpacspy
   $ python -m build
   $ pip install --user .

License
=======

**License:** Apache-2.0
